import { io, type Socket } from 'socket.io-client'

class SocketService {
  private socket: Socket | undefined

  public connect(serverUrl: string): void {
    this.socket = io(serverUrl)

    this.socket.on('connect', () => {
      console.log('Connected to Socket.IO server')
    })
  }

  public disconnect(): void {
    if (this.socket) {
      this.socket.disconnect()
    }
  }

  public joinRoom(room: string): void {
    this?.socket?.emit('join_room', { room: room, username: 'default' })
  }

  public getCaption(setCaption: (caption: string) => void): void {
    this?.socket?.on('frame', (res) => {
      console.log('response', res)
      if (res.result) {
        // eslint-disable-next-line @typescript-eslint/no-unsafe-argument
        setCaption(res.result)
      }
    })
  }

  public sendFrames(room: string, frame: any): void {
    this?.socket?.emit('frame', { room: room, frame: frame })
  }
}

export const socketService = new SocketService()
